==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/HTTPDownloadDlg.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Tiku ( )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef HTTP_DOWNLOADDLG_H
#define HTTP_DOWNLOADDLG_H

#include <wx/dialog.h>                      // Needed for wxDialog
#include <wx/process.h>                     // Needed for wxProcess

class CHTTPDownloadDlg;

class myWGetProcess: public wxProcess
{
public:
    myWGetProcess(wxEvtHandler* parent): wxProcess(parent)
    {
        myDlg = reinterpret_cast<CHTTPDownloadDlg *>(parent);
    }

    void OnTerminate(int pid,int status);

private:
    CHTTPDownloadDlg* myDlg;
};

class CHTTPDownloadDlg: public wxDialog
{
public:
    CHTTPDownloadDlg(wxWindow* parent, wxString url, wxString tempName);
    ~CHTTPDownloadDlg()
    {
        if (process)
        {
            process->Detach();
        }
    }

private:
    DECLARE_EVENT_TABLE()

    void OnBtnCancel(wxCommandEvent& evt);
    myWGetProcess* process;
};

#endif

==> xmule-1.10.0.tar.bz2: xmule-1.10.0/src/HTTPDownloadDlg.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Tiku ( )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef HTTP_DOWNLOADDLG_H
#define HTTP_DOWNLOADDLG_H

#include "wintypes.h"
#include "updownclient.h"

#include <stdint.h>                         // uint32_t
#include <wx/dialog.h>
#include <wx/process.h>

class CHTTPDownloadDlg;

class myWGetProcess : public wxProcess
{
 public:
  myWGetProcess(wxEvtHandler* parent) 
    : wxProcess(parent) {
    myDlg=(CHTTPDownloadDlg*)parent;
  };

  void OnTerminate(int pid,int status);
 private:
  CHTTPDownloadDlg* myDlg;
};

class CHTTPDownloadDlg : public wxDialog
{
 public:
  CHTTPDownloadDlg(wxWindow*parent,wxString url,wxString tempName);
  ~CHTTPDownloadDlg() {
    if(process) {
      process->Detach();
    }
  }

 private:
  DECLARE_EVENT_TABLE()

  void OnBtnCancel(wxCommandEvent& evt);
  myWGetProcess *process;
};

#endif
